@@ -1,2 +1,2 @@
-from .core_utils import start_executing, start_recording
+from .core_utils import start_executing, start_recording, write
 from .recorder_executer import Executer, Recorder, RecorderExecuter
